Broadcast class

Constructors

Broadcast({required String id, required String name, required String status, required String message, String? senderId, String? contactListId, String? scheduledAt, required String createdAt})
Broadcast.fromJson(Map<String, dynamic> json)
factory

Properties

contactListId String?
final
createdAt String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
message String
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scheduledAt String?
final
senderId String?
final
status String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited