Contact class

Constructors

Contact({required String id, String? name, String? phoneNumber, String? email, required String tenantId, required String createdAt})
Contact.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt String
final
email String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
name String?
final
phoneNumber String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tenantId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited