ContactsResource class

Constructors

ContactsResource(CastBrickClient _client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addToList(String listId, String contactId) Future<void>
create({String? phoneNumbers}) Future<void>
Create one or more contacts from comma/newline-separated phone numbers.
createList(String name) Future<String>
Create a contact list. Returns the ID of the created list.
delete(String id) Future<void>
get(String id) Future<Contact>
getList(String id) Future<ContactList>
list({int page = 1, int pageSize = 20, String? search}) Future<PagedResult<Contact>>
listLists({int page = 1, int pageSize = 20}) Future<PagedResult<ContactList>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeFromList(String listId, String contactId) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited