CreditLedgerEntry class

Constructors

CreditLedgerEntry({required String id, required num amount, required String type, required String description, required String createdAt})
CreditLedgerEntry.fromJson(Map<String, dynamic> json)
factory

Properties

amount num
final
createdAt String
final
description String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited