PagedResult<T> class

Constructors

PagedResult({required List<T> items, required int totalCount, required int pageNumber, required int totalPages, required bool hasNextPage, required bool hasPreviousPage})
PagedResult.fromJson(Map<String, dynamic> json, T itemMapper(Map<String, dynamic>))
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
hasNextPage bool
final
hasPreviousPage bool
final
items List<T>
final
pageNumber int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalCount int
final
totalPages int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited