BroadcastsResource class
Constructors
- BroadcastsResource(CastBrickClient _client)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancel(
String id) → Future< void> -
create(
{required String name, required String message, String? contactListId, String? senderId}) → Future< String> -
delete(
String id) → Future< void> -
duplicate(
String id) → Future< String> -
get(
String id) → Future< Broadcast> -
list(
{int page = 1, int pageSize = 20}) → Future< PagedResult< Broadcast> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
send(
String id) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
-
update(
String id, {required String name, required String message, String? contactListId, String? senderId, DateTime? scheduleAt}) → Future< String>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited